Package: biwt
Type: Package
Title: Compute the Biweight Mean Vector and Covariance & Correlation
        Matrice
Version: 1.0.1
Date: 2022-06-13
Author: Jo Hardin <jo.hardin@pomona.edu>
Maintainer: Jo Hardin <jo.hardin@pomona.edu>
Depends: R (>= 2.1.0), robustbase, MASS
Description: Compute multivariate location, scale, and correlation
        estimates based on Tukey's biweight M-estimator.
License: GPL-2
LazyLoad: yes
Packaged: 2022-06-13 15:27:50 UTC; jsh04747
Repository: CRAN
Date/Publication: 2022-06-13 15:50:02 UTC
NeedsCompilation: no
Built: R 4.6.0; ; 2026-04-25 23:58:40 UTC; unix
